@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
 our $DATE = '2015-06-19'; # DATE
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.16'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -169,7 +169,7 @@ sub hook_after_parse_argv {
     if ($self->log) {
         require Log::Any::Adapter;
         Log::Any::Adapter->set(
-            'ScreenColoredLevel',
+            'Screen',
             min_level => $r->{log_level} // $self->log_level,
             formatter => sub { $self->program_name . ": $_[1]" },
         );
@@ -565,7 +565,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.15 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-19.
+This document describes version 1.16 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-19.
 
 =head1 SYNOPSIS
 
